@@ -41,7 +41,8 @@ class Easyocrpipleline:
             dictionary[result[i][1]]["score"] = result[i][2]
         json_name = file.split('/')[-1].split('.')[0]
         # json log file create
-        with open("/tmp"+json_name+".json", "w") as outfile:
+        print("/tmp/testfolder/"+json_name)
+        with open("/tmp/testfolder/"+json_name+".json", "w") as outfile:
             json.dump(dictionary, outfile)
 
     def image_process(self, path):
@@ -54,6 +55,7 @@ class Easyocrpipleline:
         """
         reader = easyocr.Reader(['en'])
         result = reader.readtext(path,width_ths=0)
+        print(result)
         self.create_json(result, path)
 
     def tif_image_process(self, path):
